==> qtjambi-positioning-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiPositioning/QNmeaPositionInfoSource_shell.h <==
#ifndef QNMEAPOSITIONINFOSOURCE_SHELL_H
#define QNMEAPOSITIONINFOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPositioning/qnmeapositioninfosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPositioning/qgeopositioninfo.h>
#include <QtPositioning/qgeopositioninfosource.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QNmeaPositionInfoSource_shell : public QNmeaPositionInfoSource, public QtJambiShellInterface
{
public:
    QNmeaPositionInfoSource_shell(QNmeaPositionInfoSource::UpdateMode updateMode0, QObject* parent1 = nullptr);
    ~QNmeaPositionInfoSource_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoPositionInfoSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QGeoPositionInfo lastKnownPosition(bool fromSatellitePositioningMethodsOnly0) const override;
    int minimumUpdateInterval() const override;
    bool parsePosInfoFromNmeaData(const char* data0, int size1, QGeoPositionInfo* posInfo2, bool* hasFix3) override;
    void requestUpdate(int timeout0) override;
    void setPreferredPositioningMethods(QGeoPositionInfoSource::PositioningMethods methods0) override;
    void setUpdateInterval(int msec0) override;
    void startUpdates() override;
    void stopUpdates() override;
    QGeoPositionInfoSource::PositioningMethods supportedPositioningMethods() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNmeaPositionInfoSource_access : public QNmeaPositionInfoSource
{
    jint __qt_error_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_lastKnownPosition_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean fromSatellitePositioningMethodsOnly0) const;
    jint __qt_minimumUpdateInterval_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_parsePosInfoFromNmeaData_const_char_ptr_int_QGeoPositionInfo_ptr_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    void __qt_requestUpdate_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timeout0);
    void __qt_setUpdateInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msec0);
    void __qt_startUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stopUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_supportedPositioningMethods_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QNMEAPOSITIONINFOSOURCE_SHELL_H

==> qtjambi-positioning-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiPositioning/QNmeaPositionInfoSource_shell.h <==
#ifndef QNMEAPOSITIONINFOSOURCE_SHELL_H
#define QNMEAPOSITIONINFOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPositioning/qnmeapositioninfosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qbytearrayview.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPositioning/qgeopositioninfo.h>
#include <QtPositioning/qgeopositioninfosource.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QNmeaPositionInfoSource_shell : public QNmeaPositionInfoSource, public QtJambiShellInterface
{
public:
    QNmeaPositionInfoSource_shell(QNmeaPositionInfoSource::UpdateMode updateMode0, QObject* parent1 = nullptr);
    ~QNmeaPositionInfoSource_shell() override;

    QVariant backendProperty(const QString& name0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoPositionInfoSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QGeoPositionInfo lastKnownPosition(bool fromSatellitePositioningMethodsOnly0) const override;
    int minimumUpdateInterval() const override;
    bool parsePosInfoFromNmeaData(const char* data0, int size1, QGeoPositionInfo* posInfo2, bool* hasFix3) override;
    void requestUpdate(int timeout0) override;
    bool setBackendProperty(const QString& name0, const QVariant& value1) override;
    void setPreferredPositioningMethods(QGeoPositionInfoSource::PositioningMethods methods0) override;
    void setUpdateInterval(int msec0) override;
    void startUpdates() override;
    void stopUpdates() override;
    QGeoPositionInfoSource::PositioningMethods supportedPositioningMethods() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNmeaPositionInfoSource_access : public QNmeaPositionInfoSource
{
    jobject __qt_parsePosInfoFromNmeaData_QByteArrayView_QGeoPositionInfo_ptr_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0);
    void __qt_setError_QGeoPositionInfoSource_Error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint positionError0);
    jint __qt_error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_lastKnownPosition_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean fromSatellitePositioningMethodsOnly0) const;
    jint __qt_minimumUpdateInterval(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_parsePosInfoFromNmeaData_const_char_ptr_int_QGeoPositionInfo_ptr_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    void __qt_requestUpdate_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timeout0);
    void __qt_setUpdateInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msec0);
    void __qt_startUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stopUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_supportedPositioningMethods(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QNMEAPOSITIONINFOSOURCE_SHELL_H
